@@ -18,21 +18,22 @@
 #include <qobjectlist.h>
 #include <qobjectdict.h>
 
+#include <klocale.h>
+
 #include "navview.h"
 #include "navviewitem.h"
 
-NavView::NavView(QWidget *parent, const char *name ) : QListView(parent,name)
+NavView::NavView(QWidget *parent, const char *name ) : KListView(parent,name)
 {
-  addColumn( "Name" );
-  addColumn( "Type" );
+  addColumn( i18n( "Name" ) );
+  addColumn( i18n( "Type" ) );
 
   setRootIsDecorated( true );
   setAllColumnsShowFocus( true );
+  setFullWidth( true );
 
   connect( this, SIGNAL( selectionChanged( QListViewItem * ) ),
-	   this, SLOT( selectItem( QListViewItem * ) ) );
-  connect( this, SIGNAL( expanded( QListViewItem * ) ),
-	   this, SLOT( expandItem( QListViewItem * ) ) );
+           this, SLOT( selectItem( QListViewItem * ) ) );
 }
 
 NavView::~NavView(){
@@ -40,39 +41,38 @@ NavView::~NavView(){
 
 void NavView::buildTree()
 {
-  //
-  // Add root QObjects
-  //
   const QObjectList *roots = QObject::objectTrees();
   QObjectListIt it( *roots );
 
   QObject * obj;
-  while ( (obj=it.current()) != 0 ) {
+  while ( (obj = it.current()) != 0 ) {
     ++it;
-    new NavViewItem( this, obj );
+    NavViewItem *item = new NavViewItem( this, obj );
+    createSubTree( item );
   }
 }
 
-void NavView::selectItem( QListViewItem *i )
+void NavView::expandVisibleTree()
 {
-  NavViewItem *ni = (NavViewItem *) i;
-  emit selected( ni->data );
+  QListViewItemIterator it( this, QListViewItemIterator::Visible |
+                                  QListViewItemIterator::Expandable );
+
+  while ( it.current() ) {
+    setOpen( *it, true );
+    ++it;
+  }
 }
 
-void NavView::expandItem( QListViewItem *i )
+void NavView::selectItem( QListViewItem *item )
 {
-  NavViewItem *ni = (NavViewItem *) i;
+  NavViewItem *navItem = static_cast<NavViewItem*>( item );
 
-  //
-  // Clear old data.
-  //
-  while( ni->childCount() )
-    delete ni->firstChild();
+  emit selected( navItem->data );
+}
 
-  //
-  // Populate
-  //
-  const QObjectList *kids = ni->data->children();
+void NavView::createSubTree( NavViewItem *parent )
+{
+  const QObjectList *kids = parent->data->children();
   if ( !kids )
     return;
 
@@ -80,7 +80,9 @@ void NavView::expandItem( QListViewItem *i )
   QObjectListIt it( *kids );
   while ( (obj=it.current()) != 0 ) {
     ++it;
-    new NavViewItem( ni, obj );
+    NavViewItem *item = new NavViewItem( parent, obj );
+    createSubTree( item );
   }
 }
+
 #include "navview.moc"
