@@ -176,13 +176,13 @@ void UMLApp::initActions() {
     createStandardStatusBarAction();
     setStandardToolBarMenuEnabled(true);
     selectAll = KStdAction::selectAll(this,  SLOT( slotSelectAll() ), actionCollection());
-    fileExportDocbook = new KAction(i18n("&Export model to DocBook"), 0, 
-                                    this, SLOT( slotFileExportDocbook() ), 
+    fileExportDocbook = new KAction(i18n("&Export model to DocBook"), 0,
+                                    this, SLOT( slotFileExportDocbook() ),
                                     actionCollection(), "file_export_docbook");
-    fileExportXhtml = new KAction(i18n("&Export model to XHTML"), 0, 
+    fileExportXhtml = new KAction(i18n("&Export model to XHTML"), 0,
                                     this, SLOT( slotFileExportXhtml() ),
                                     actionCollection(), "file_export_xhtml");
-    
+
     classWizard = new KAction(i18n("&New Class Wizard..."),0,this,SLOT(slotClassWizard()),
                               actionCollection(),"class_wizard");
     new KAction(i18n("&Add Default Datatypes for Active Language"), 0, this,
@@ -457,6 +457,7 @@ void UMLApp::initView() {
 
     m_listDock = createDockWidget( "Model", 0L, 0L, i18n("&Tree View") );
     m_listView = new UMLListView(m_listDock ,"LISTVIEW");
+    //m_listView->setSorting(-1);
     m_listView->setDocument(m_doc);
     m_listView->init();
     m_listDock->setWidget(m_listView);
@@ -733,15 +734,6 @@ bool UMLApp::slotFileSaveAs()
         if(url.isEmpty())
             cont = false;
         else {
-            // now check that we have a file extension; standard will be plain xmi
-            QString file = url.path(-1);
-            QFileInfo info(file);
-            ext = info.extension();
-            if (ext != "xmi" && ext != "xmi.tgz" && ext != "xmi.tar.bz2")
-            {
-                url.setFileName(url.fileName() + ".xmi");
-                ext = "xmi";
-            }
             QDir d = url.path(-1);
 
             if(QFile::exists(d.path())) {
@@ -805,7 +797,7 @@ void UMLApp::slotFileExportDocbook()
 {
   DocbookGenerator().generateDocbookForProject();
 }
-    
+
 void UMLApp::slotFileExportXhtml()
 {
   if (m_xhtmlGenerator != 0)
@@ -816,7 +808,7 @@ void UMLApp::slotFileExportXhtml()
   m_xhtmlGenerator->generateXhtmlForProject();
   connect(m_xhtmlGenerator,SIGNAL(finished()),this,SLOT(slotXhtmlDocGenerationFinished()));
 }
-    
+
 void UMLApp::slotEditUndo() {
     m_doc->loadUndoData();
     slotStatusMsg(i18n("Ready."));
@@ -1096,7 +1088,7 @@ void UMLApp::readOptionState() {
     Settings::OptionState& optionState = Settings::getOptionState();
     optionState.generalState.undo = m_config -> readBoolEntry( "undo", true );
     optionState.generalState.tabdiagrams = m_config -> readBoolEntry("tabdiagrams", false);
-#if defined (BUG84739_FIXED)
+#if defined (WORK_ON_BUG_126262)
     optionState.generalState.newcodegen = m_config -> readBoolEntry("newcodegen", false);
 #else
     optionState.generalState.newcodegen = false;
@@ -1313,6 +1305,7 @@ bool UMLApp::activeLanguageIsCaseSensitive() {
 QString UMLApp::activeLanguageScopeSeparator() {
     Uml::Programming_Language pl = getActiveLanguage();
     if (pl == Uml::pl_Ada ||
+        pl == Uml::pl_CSharp ||
         pl == Uml::pl_Pascal ||
         pl == Uml::pl_Java ||
         pl == Uml::pl_JavaScript ||
